summaryrefslogtreecommitdiffstats
path: root/src/mbedTLS++/X509Cert.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/mbedTLS++/X509Cert.h (renamed from src/PolarSSL++/X509Cert.h)16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/PolarSSL++/X509Cert.h b/src/mbedTLS++/X509Cert.h
index 45f714d14..4234308ff 100644
--- a/src/PolarSSL++/X509Cert.h
+++ b/src/mbedTLS++/X509Cert.h
@@ -1,7 +1,7 @@
-
+
// X509Cert.h
// Declares the cX509Cert class representing a wrapper over X509 certs in PolarSSL
@@ -9,7 +9,7 @@
#pragma once
-#include "polarssl/x509_crt.h"
+#include "mbedtls/x509_crt.h"
@@ -17,21 +17,21 @@
class cX509Cert
{
- friend class cSslContext;
+ friend class cSslConfig;
public:
cX509Cert(void);
~cX509Cert(void);
/** Parses the certificate chain data into the context.
- Returns 0 on succes, or PolarSSL error code on failure. */
+ Returns 0 on succes, or mbedTLS error code on failure. */
int Parse(const void * a_CertContents, size_t a_Size);
protected:
- x509_crt m_Cert;
+ mbedtls_x509_crt m_Cert;
- /** Returns the internal cert ptr. Only use in PolarSSL API calls. */
- x509_crt * GetInternal(void) { return &m_Cert; }
+ /** Returns the internal cert ptr. Only use in mbedTLS API calls. */
+ mbedtls_x509_crt * GetInternal(void) { return &m_Cert; }
} ;
typedef std::shared_ptr<cX509Cert> cX509CertPtr;
@@ -1,7 +1,7 @@
// X509Cert.h
-// Declares the cX509Cert class representing a wrapper over X509 certs in PolarSSL
+// Declares the cX509Cert class representing a wrapper over X509 certs in mbedTLS
#pragma once